pub trait TryInto<T> {
type Error;
// Required method
fn try_into(self) -> Result<T, Self::Error>;
}Expand description
This trait is at the time of this writing a nightly-only experimental API and so we just replicate it here, so it will be easy to switch to it later on.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".